.. currentmodule:: sardana.pool.poolioregister

:mod:`~sardana.pool.poolioregister`
==========================================

.. automodule:: sardana.pool.poolioregister

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`PoolIORegister`

PoolIORegister
-------------------

.. inheritance-diagram:: PoolIORegister
    :parts: 1
    
.. autoclass:: PoolIORegister
    :show-inheritance:
    :members:
    :undoc-members:
